@@ -264,16 +264,11 @@ bool aws_tls_is_alpn_available(void) {
 
 bool aws_tls_is_cipher_pref_supported(enum aws_tls_cipher_pref cipher_pref) {
     switch (cipher_pref) {
-        case AWS_IO_TLS_CIPHER_PREF_SYSTEM_DEFAULT:
-            return true;
-            /* PQ Crypto no-ops on android for now */
-#ifndef ANDROID
-        case AWS_IO_TLS_CIPHER_PREF_PQ_TLSV1_2_2024_10:
-            return true;
         case AWS_IO_TLS_CIPHER_PREF_PQ_DEFAULT:
+        case AWS_IO_TLS_CIPHER_PREF_PQ_TLSV1_2_2024_10:
+        case AWS_IO_TLS_CIPHER_PREF_SYSTEM_DEFAULT:
+        case AWS_IO_TLS_CIPHER_PREF_TLSV1_2_2025_07:
             return true;
-#endif
-
         default:
             return false;
     }
@@ -1340,7 +1335,7 @@ static struct aws_channel_handler *s_new_tls_handler(
             (void *)&s2n_handler->handler,
             aws_string_c_str(options->alpn_list));
 
-        const char protocols_cpy[4][128];
+        const char protocols_cpy[4][128] = {{0}};
         AWS_ZERO_ARRAY(protocols_cpy);
         size_t protocols_size = 4;
         if (s_parse_protocol_preferences(options->alpn_list, protocols_cpy, &protocols_size)) {
@@ -1403,7 +1398,8 @@ struct aws_channel_handler *aws_tls_server_handler_new(
     return s_new_tls_handler(allocator, options, slot, S2N_SERVER);
 }
 
-static void s_s2n_ctx_destroy(struct s2n_ctx *s2n_ctx) {
+static void s_s2n_ctx_destroy(void *user_data) {
+    struct s2n_ctx *s2n_ctx = user_data;
     if (s2n_ctx != NULL) {
         if (s2n_ctx->s2n_config) {
             s2n_config_free(s2n_ctx->s2n_config);
@@ -1447,11 +1443,6 @@ static struct aws_tls_ctx *s_tls_ctx_new(
     struct aws_allocator *alloc,
     const struct aws_tls_ctx_options *options,
     s2n_mode mode) {
-    struct s2n_ctx *s2n_ctx = aws_mem_calloc(alloc, 1, sizeof(struct s2n_ctx));
-
-    if (!s2n_ctx) {
-        return NULL;
-    }
 
     if (!aws_tls_is_cipher_pref_supported(options->cipher_pref)) {
         aws_raise_error(AWS_IO_TLS_CIPHER_PREF_UNSUPPORTED);
@@ -1459,6 +1450,8 @@ static struct aws_tls_ctx *s_tls_ctx_new(
         return NULL;
     }
 
+    struct s2n_ctx *s2n_ctx = aws_mem_calloc(alloc, 1, sizeof(struct s2n_ctx));
+
     s2n_ctx->ctx.alloc = alloc;
     s2n_ctx->ctx.impl = s2n_ctx;
     aws_ref_count_init(&s2n_ctx->ctx.ref_count, s2n_ctx, (aws_simple_completion_callback *)s_s2n_ctx_destroy);
@@ -1519,14 +1512,14 @@ static struct aws_tls_ctx *s_tls_ctx_new(
                 security_policy = "AWS-CRT-SDK-TLSv1.1-2023";
                 break;
             case AWS_IO_TLSv1_2:
-                security_policy = "AWS-CRT-SDK-TLSv1.2-2023";
+                security_policy = "AWS-CRT-SDK-TLSv1.2-2025-PQ";
                 break;
             case AWS_IO_TLSv1_3:
-                security_policy = "AWS-CRT-SDK-TLSv1.3-2023";
+                security_policy = "AWS-CRT-SDK-TLSv1.3-2025-PQ";
                 break;
             case AWS_IO_TLS_VER_SYS_DEFAULTS:
             default:
-                security_policy = "AWS-CRT-SDK-TLSv1.0-2023";
+                security_policy = "AWS-CRT-SDK-TLSv1.0-2025-PQ";
         }
     }
 
@@ -1537,11 +1530,17 @@ static struct aws_tls_ctx *s_tls_ctx_new(
             break;
         case AWS_IO_TLS_CIPHER_PREF_PQ_DEFAULT:
             /* The specific PQ policy used here may change over time. */
-            security_policy = "AWS-CRT-SDK-TLSv1.2-2023-PQ";
+            security_policy = "AWS-CRT-SDK-TLSv1.2-2025-PQ";
             break;
         case AWS_IO_TLS_CIPHER_PREF_PQ_TLSV1_2_2024_10:
             security_policy = "AWS-CRT-SDK-TLSv1.2-2023-PQ";
             break;
+        case AWS_IO_TLS_CIPHER_PREF_TLSV1_2_2025_07:
+            security_policy = "AWS-CRT-SDK-TLSv1.2-2025";
+            break;
+        case AWS_IO_TLS_CIPHER_PREF_TLSV1_0_2023_06:
+            security_policy = "AWS-CRT-SDK-TLSv1.2-2025";
+            break;
         default:
             AWS_LOGF_ERROR(AWS_LS_IO_TLS, "Unrecognized TLS Cipher Preference: %d", options->cipher_pref);
             aws_raise_error(AWS_IO_TLS_CIPHER_PREF_UNSUPPORTED);
@@ -1549,6 +1548,14 @@ static struct aws_tls_ctx *s_tls_ctx_new(
     }
 
     AWS_ASSERT(security_policy != NULL);
+
+    AWS_LOGF_DEBUG(
+        AWS_LS_IO_TLS,
+        "Set security policy to %s (minimum_tls_version: %d; cipher_pref: %d)",
+        security_policy,
+        (int)options->minimum_tls_version,
+        (int)options->cipher_pref);
+
     if (s2n_config_set_cipher_preferences(s2n_ctx->s2n_config, security_policy)) {
         AWS_LOGF_ERROR(
             AWS_LS_IO_TLS,
@@ -1714,7 +1721,7 @@ static struct aws_tls_ctx *s_tls_ctx_new(
 
     if (options->alpn_list) {
         AWS_LOGF_DEBUG(AWS_LS_IO_TLS, "ctx: Setting ALPN list %s", aws_string_c_str(options->alpn_list));
-        const char protocols_cpy[4][128];
+        const char protocols_cpy[4][128] = {{0}};
         AWS_ZERO_ARRAY(protocols_cpy);
         size_t protocols_size = 4;
         if (s_parse_protocol_preferences(options->alpn_list, protocols_cpy, &protocols_size)) {
